==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>قىستۇرما %1 بىلەن سىستېما نەشرى ماسلاشمايدۇ</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>چىقىرىۋېتىش</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>كۆكچىش تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>كۆكچىشنى ئېچىش</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>كۆكچىش تەڭشىكى</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ئۇلاندى</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>ئۇلىنىۋاتىدۇ...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>كۆكچىش</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>كۆكچىش</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>كۇنۇپكا تاختىسى ئورۇنلاشتۇرۇلۇشى قوشۇش</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>چېسىلا ۋە ۋاقىت</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 سائەتلىك</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 سائەتلىك</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>ۋاقىت تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>تورنى قوزغىتىش </translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>تورنى تاقاش</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>تور تەڭشىكى </translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>راستلا ئەخلەت ساندۇقىدىكى %1 تۈرلۈك مەزمۇننى تازىلامسىز؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>بۇ مەشغۇلاتنى ئەسلىگە قايتۇرغىلى بولمايدۇ</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>نامەلۇم ئۈسكۈنە</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>سىغىمى نامەلۇم</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>دېسكا</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ئوچۇق</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>ھەممىنى ئۆچۈرۈش </translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>ئۈستەليۈزى قوزغاتقۇچ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>مودا ھالەت</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>يۇقىرى ئۈنۈملۈك ھالەت</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>ئۈستى</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>ئاستى تەرەپ</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>سول تەرەپ</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>ئوڭ تەرەپ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>كۆرسىتىش</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>يوشۇرۇش</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>ئەقلىي يوشۇرۇش</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>ھالىتى</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>ئورنى</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>ھالىتى </translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>قىستۇرما</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>كۆپ ۋەزىپە كۆرۈنۈشى</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>چىقىرىۋېتىش</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>سىملىق تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>سىملىق تورنى ئېچىش</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>سىمسىز تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>سىمسىز تورنى ئېچىش</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>تورنى تاقاش</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>تورنى قوزغىتىش </translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>تور تەڭشىكى </translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>ئۈسكىنە چەكلەش</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>سىمسىز تور:  %1</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>سىملىق تور:  %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>ئۇلانمىدى</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>ئۇلىنىۋاتىدۇ</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>ئۇلاندى ، لېكىن تورغا چىققىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>تور سىمى ئۇلانمىغان </translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>سىملىق تور</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>ئۇلىنىش مەغلۇپ بولدى</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>تور</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>سىملىق تور</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>سىملىق تور%1</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>ئېكران كۇنۇپكىسى</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەك</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>قۇۋۋەت</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>باتارىيە تەڭشىكى</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>توك %1 قالدى، %2 مىنۇت يېتىدۇ</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>توك %1 قالدى، %2 سائەت %3 مىنۇت يېتىدۇ</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>زەرەتلىنىۋاتىدۇ%1، يەنە %2 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>زەرەتلىنىۋاتىدۇ%1، يەنە %2 سائەت %3 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>توشتى</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>توك%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>زەرەتلەۋاتىدۇ%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>توك%1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>توك%1، توشتى</translation>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>ئۈستەل يۈزىنى كۆرۈش</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>تۇرغۇنلارنى چىقىرىۋېتىش</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>قۇۋۋەت</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ئېسىپ قويۇش</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ئۇخلاش ھالىتى</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قۇلۇپلاش</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>تىزىمدىن چېكىنىش</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>ئاكونت ئالمىشىش</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>باتارىيە تەڭشىكى</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتا قوزغىتىش</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>ئۈسكۈنە</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>ئاۋازلىق</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>ئاۋازسىز</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ئاۋاز تەڭشىكى</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>ئاۋاز%1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ئاۋاز</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>ئەخلەت ساندۇقى</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>ئەخلەت ساندۇقى - %1ھۆججەت</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>ئەخلەت ساندۇقى - %1ھۆججەت</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>ئوچۇق</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>قۇرۇق</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>سىستېما يۈكلەنگەن دىسكا</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>سىمسىز تور</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>سىمسىز تور%1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.38.1.orig.tar.xz: dde-dock-5.5.38.1/translations/dde-dock_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>قىستۇرما %1 بىلەن سىستېما نەشرى ماسلاشمايدۇ</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation>ئۇچۇش ھالىتى</translation>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>ئۇچۇش ھالىتىنى ئېچىش</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>كۆكچىشنى ئېچىش</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation>ئۇچۇش ھالىتى تەڭشىكى</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation> ئۇچۇش ھالىتىنى تاقاش</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>ئۇچۇش ھالىتى</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>چىقىرىۋېتىش</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>كۆكچىش تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>كۆكچىشنى ئېچىش</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>كۆكچىش تەڭشىكى</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 ئۇلاندى</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>ئۇلىنىۋاتىدۇ...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>كۆكچىش</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>كۆكچىشنى تاقاش</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>كۆكچىش</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>كۇنۇپكا تاختىسى ئورۇنلاشتۇرۇلۇشى قوشۇش</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>چېسىلا ۋە ۋاقىت</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 سائەتلىك</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 سائەتلىك</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>ۋاقىت تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>راستلا ئەخلەت ساندۇقىدىكى %1 تۈرلۈك مەزمۇننى تازىلامسىز؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>بۇ مەشغۇلاتنى ئەسلىگە قايتۇرغىلى بولمايدۇ</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>نامەلۇم ئۈسكۈنە</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>سىغىمى نامەلۇم</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>دېسكا</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ئوچۇق</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>ھەممىنى ئۆچۈرۈش </translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>ئۈستەليۈزى قوزغاتقۇچ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation>بىخەتەر ھالەتتىن چېكىنىش</translation>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation>ۋەزىپە ئىستونى بىخەتەرلىك ھالىتى</translation>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation>ۋەزىپە ئىستونى بىخەتەر ھالەتكە كىردى، چېكىنگەندىن كېيىن نورمال كۆرۈنىدۇ</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>مودا ھالەت</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>يۇقىرى ئۈنۈملۈك ھالەت</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>ئۈستى</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>ئاستى تەرەپ</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>سول تەرەپ</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>ئوڭ تەرەپ</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>كۆرسىتىش</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>يوشۇرۇش</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>ئەقلىي يوشۇرۇش</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>ھالىتى</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>ئورنى</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>ھالىتى </translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation>ۋەزىپە ئىستونى تەڭشىكى</translation>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>چوڭلۇقى</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>كۆپ ئېكرانلىق كۆرسىتىش تەڭشىكى</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation>قىستۇرما رايونى</translation>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation>ۋەزىپە ئىستونى قىستۇرما رايونىدا كۆرسىتىلىدىغان سىنبەلگىنى تاللاڭ</translation>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>مودا ھالەت</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>يۇقىرى ئۈنۈملۈك ھالەت</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>ھالىتى</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>ئۈستى</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>ئاستى</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>سول</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>ئوڭ</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>ئورنى</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation>داۋاملىق كۆرسىتىش</translation>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>داۋاملىق يوشۇرۇش</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>ئەقلىي يوشۇرۇش</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>ھالىتى </translation>
    </message>
    <message>
        <source>Small</source>
        <translation>كىچىك</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>چوڭ</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation>ۋەزىپە ئىستونىنىڭ ئورنى</translation>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation>مائۇسنىڭ ئورنىغا ئەگىشىپ كۆرۈنسۇن</translation>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation>ئاساسىي ئېكراندىلا كۆرۈنسۇن</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>كۆپ ۋەزىپە كۆرۈنۈشى</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>قالدۇقلىرىنى چىقىرىۋېتىش</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>ئېكران كۇنۇپكىسى</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>تەڭشەك</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>توك مەنبە</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>باتارىيە تەڭشىكى</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>توك %1 قالدى، %2 مىنۇت يېتىدۇ</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>توك %1 قالدى، %2 سائەت %3 مىنۇت يېتىدۇ</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>زەرەتلىنىۋاتىدۇ%1، يەنە %2 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>زەرەتلىنىۋاتىدۇ%1، يەنە %2 سائەت %3 مىنۇتتا توشىدۇ</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>توكى%1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>زەرەتلەۋاتىدۇ%1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>توك%1...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>توك%1، توشتى</translation>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>ۋەزىپە ئىستونى</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>ئۈستەل يۈزىنى كۆرۈش</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>تۇرغۇنلارنى چىقىرىۋېتىش</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>توك مەنبە</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>تاقاش</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>ئېسىپ قويۇش</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>ئۇخلاش ھالىتى</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قۇلۇپلاش</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>تىزىمدىن چېكىنىش</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>ئاكونت ئالمىشىش</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>باتارىيە تەڭشىكى</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>قايتا قوزغىتىش</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>ئۈسكۈنە</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>ئاۋازلىق</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>ئاۋازسىز</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>ئاۋاز تەڭشىكى</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>ئاۋاز%1</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>ئاۋاز</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>ئەخلەت ساندۇقى</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>ئەخلەت ساندۇقى - %1ھۆججەت</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>ئەخلەت ساندۇقى - %1ھۆججەت</translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>ئەخلەت ساندۇقىغا يۆتكەش</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>ئوچۇق</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>قۇرۇق</translation>
    </message>
</context>
</TS>
